@@ -89,7 +89,7 @@ class SchemaNode:
         path_to_element: List[Union[str, int]],
         html_id: str,
         is_property: bool = False,
-        literal: Union[str, int] = None,
+        literal: Union[str, int, bool] = None,
         keywords: Dict[str, Union["SchemaNode", str, List[str]]] = None,
         array_items: List["SchemaNode"] = None,
         refers_to: "SchemaNode" = None,
@@ -349,7 +349,7 @@ def build_intermediate_representation(
                     other_user.refers_to = current_node
                     current_node.is_displayed = True
                     return found_reference
-                else:
+                elif other_user and other_user.refers_to:
                     # Both nodes are the same depth. The other having been seen first,
                     # this node will be hidden and linked to the other node
                     current_node.is_displayed = False
