@@ -80,6 +80,57 @@ def test_references() -> None:
             "Contents of propertyA in final.json",
         ],
     )
+    tests.html_schema_doc_asserts.assert_types(
+        soup,
+        [
+            "object",  # root
+            "string",  # a_gift
+            "object",  # anchor_with_slash
+            "string",  # anchor_with_slash -> propertyA
+            "array of string",  # anchor_no_slash
+            "string",  # anchor_no_slash items
+            "string",  # anchor_nested_reference
+            "string",  # same_file_anchor_with_slash
+            "object",  # other_file_anchor
+            "boolean",  # with_wrap
+            "object",  # other_file_only
+            "string",  # not_a_string, not
+            "object",  # multi_hierarchy_reference
+            "string",  # multi_hierarchy_reference -> propertyA
+        ],
+    )
+
+
+def test_additional_properties() -> None:
+    """Test rendering a schema with additionalProperties: true, false, and a complex schema"""
+    soup = generate_case("additional_properties")
+
+    tests.html_schema_doc_asserts.assert_property_names(
+        soup,
+        [
+            "subType1",
+            "subProp1",
+            "subType2",
+            "subProp2",
+            "Additional Properties",  # from subType2
+            "Additional Properties",  # from top level of schema
+            "propA",  # schema for top level additionalProperties
+        ],
+    )
+    tests.html_schema_doc_asserts.assert_descriptions(
+        soup,
+        [
+            "A sub type with additionalProperties false.",
+            "A sub type with additionalProperties true.",
+            "additionalProperties schema.",
+        ],
+    )
+
+    # badge for the first sub type with additionalProperties: false
+    badges = soup.find_all("span", class_=["no-additional"])
+    assert len(badges) == 1
+    badge = badges[0]
+    assert badge.text == "No Additional Properties"
 
 
 def test_top_level_array() -> None:
